==> libgnomedb-3.0.0.tar.bz2: libgnomedb-3.0.0/libgnomedb-graph/gnome-db-canvas-entity.h <==
/* gnome-db-canvas-entity.h
 *
 * Copyright (C) 2004 Vivien Malerba
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef __GNOME_DB_CANVAS_ENTITY__
#define __GNOME_DB_CANVAS_ENTITY__

#include "gnome-db-canvas-item.h"
#include <libgnomedb/gnome-db-decl.h>

G_BEGIN_DECLS

/*
 * 
 * "Drag item" GnomeCanvas item: a GnomeDbCanvasItem item which is used to represent
 * an element being dragged, and destroys itself when the mouse button is released
 *
 */

#define GNOME_DB_TYPE_CANVAS_ENTITY          (gnome_db_canvas_entity_get_type())
#define GNOME_DB_CANVAS_ENTITY(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_canvas_entity_get_type(), GnomeDbCanvasEntity)
#define GNOME_DB_CANVAS_ENTITY_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_canvas_entity_get_type (), GnomeDbCanvasEntityClass)
#define GNOME_DB_IS_CANVAS_ENTITY(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_canvas_entity_get_type ())


/* struct for the object's data */
struct _GnomeDbCanvasEntity
{
	GnomeDbCanvasItem           object;

	GnomeDbCanvasEntityPrivate *priv;
};

/* struct for the object's class */
struct _GnomeDbCanvasEntityClass
{
	GnomeDbCanvasItemClass   parent_class;
};

/* generic widget's functions */
GType          gnome_db_canvas_entity_get_type       (void);
GnomeDbCanvasField *gnome_db_canvas_entity_get_field_item (GnomeDbCanvasEntity *ce, GdaEntityField *field);
gdouble        gnome_db_canvas_entity_get_field_ypos (GnomeDbCanvasEntity *ce, GdaEntityField *field);

G_END_DECLS

#endif

==> libgnomedb-3.1.1.tar.bz2: libgnomedb-3.1.1/libgnomedb-graph/gnome-db-canvas-entity.h <==
/* gnome-db-canvas-entity.h
 *
 * Copyright (C) 2004 Vivien Malerba
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef __GNOME_DB_CANVAS_ENTITY__
#define __GNOME_DB_CANVAS_ENTITY__

#include "gnome-db-canvas-item.h"
#include <libgnomedb/gnome-db-decl.h>

G_BEGIN_DECLS

/*
 * 
 * "Drag item" GnomeCanvas item: a GnomeDbCanvasItem item which is used to represent
 * an element being dragged, and destroys itself when the mouse button is released
 *
 */

#define GNOME_DB_TYPE_CANVAS_ENTITY          (gnome_db_canvas_entity_get_type())
#define GNOME_DB_CANVAS_ENTITY(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_canvas_entity_get_type(), GnomeDbCanvasEntity)
#define GNOME_DB_CANVAS_ENTITY_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_canvas_entity_get_type (), GnomeDbCanvasEntityClass)
#define GNOME_DB_IS_CANVAS_ENTITY(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_canvas_entity_get_type ())


/* struct for the object's data */
struct _GnomeDbCanvasEntity
{
	GnomeDbCanvasItem           object;

	GnomeDbCanvasEntityPrivate *priv;
};

/* struct for the object's class */
struct _GnomeDbCanvasEntityClass
{
	GnomeDbCanvasItemClass   parent_class;
};

/* generic widget's functions */
GType          gnome_db_canvas_entity_get_type       (void) G_GNUC_CONST;
GnomeDbCanvasField *gnome_db_canvas_entity_get_field_item (GnomeDbCanvasEntity *ce, GdaEntityField *field);
gdouble        gnome_db_canvas_entity_get_field_ypos (GnomeDbCanvasEntity *ce, GdaEntityField *field);

G_END_DECLS

#endif
